@@ -1,9 +1,4 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
-#
-# configwindow.py
-#
-# Copyright 2011 - 2019 Patrick Ulbrich <zulu99@gmx.net>
+# Copyright 2011 - 2020 Patrick Ulbrich <zulu99@gmx.net>
 # Copyright 2011 Ralf Hersel <ralf.hersel@gmx.net>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -35,7 +30,6 @@ from Mailnag.common.i18n import _
 from Mailnag.common.utils import get_data_file
 from Mailnag.common.config import read_cfg, write_cfg
 from Mailnag.common.accounts import Account, AccountManager
-from Mailnag.common.credentialstore import CredentialStore
 from Mailnag.common.plugins import Plugin
 from Mailnag.configuration.accountdialog import AccountDialog
 from Mailnag.configuration.plugindialog import PluginDialog
@@ -72,7 +66,7 @@ class ConfigWindow:
 		#
 		# accounts page
 		#
-		self._accountman = AccountManager(CredentialStore.from_string(self._cfg.get('core', 'credentialstore')))
+		self._accountman = AccountManager()
 
 		self._treeview_accounts = builder.get_object("treeview_accounts")
 		self._liststore_accounts = builder.get_object("liststore_accounts")
@@ -103,17 +97,11 @@ class ConfigWindow:
 		self._button_edit_plugin = builder.get_object("btn_edit_plugin")
 		self._button_edit_plugin.set_sensitive(False)
 		
-		def renderer_plugin_enabled_func(column, cell_renderer, model, iter, data):
-			plugin = model.get_value(iter, 0)
-			name, desc, ver, author, mandatory = plugin.get_manifest()
-			cell_renderer.set_sensitive(not mandatory)
-		
 		renderer_plugin_enabled = Gtk.CellRendererToggle()
 		renderer_plugin_enabled.connect("toggled", self._on_plugin_toggled)
 		column_plugin_enabled = Gtk.TreeViewColumn(_('Enabled'), renderer_plugin_enabled)
 		column_plugin_enabled.add_attribute(renderer_plugin_enabled, "active", 1)
 		column_plugin_enabled.set_alignment(0.5)
-		column_plugin_enabled.set_cell_data_func(renderer_plugin_enabled, renderer_plugin_enabled_func)
 		self._treeview_plugins.append_column(column_plugin_enabled)
 
 		renderer_plugin_name = Gtk.CellRendererText()
@@ -146,14 +134,14 @@ class ConfigWindow:
 		
 		# load plugins
 		enabled_lst = self._cfg.get('core', 'enabled_plugins').split(',')
-		enabled_lst = filter(lambda s: s != '', map(lambda s: s.strip(), enabled_lst))
+		enabled_lst = [s for s in [s.strip() for s in enabled_lst] if s != '']
 		
 		plugins = Plugin.load_plugins(self._cfg)
-		plugins.sort(key = lambda p : (not p.get_manifest()[4], p.get_manifest()[0]))
+		plugins.sort(key = lambda p : p.get_manifest()[0])
 		
 		for plugin in plugins:
-			name, desc, ver, author, mandatory = plugin.get_manifest()
-			enabled = True if (plugin.get_modname() in enabled_lst) or mandatory else False
+			name, desc, ver, author = plugin.get_manifest()
+			enabled = True if (plugin.get_modname() in enabled_lst) else False
 			description = '<b>%s</b> (%s)\n%s' % (name, ver, desc)
 			row = [plugin, enabled, description]
 			self._liststore_plugins.append(row)
@@ -180,7 +168,7 @@ class ConfigWindow:
 			if len(config) > 0:
 				if not self._cfg.has_section(modname):
 					self._cfg.add_section(modname)
-				for k, v in config.iteritems():
+				for k, v in config.items():
 					self._cfg.set(modname, k, v)
 		
 		self._cfg.set('core', 'enabled_plugins', enabled_plugins)
@@ -283,19 +271,22 @@ class ConfigWindow:
 		aboutdialog.set_version(APP_VERSION)
 		aboutdialog.set_program_name(PACKAGE_NAME.title())
 		aboutdialog.set_comments(_("An extensible mail notification daemon."))
-		aboutdialog.set_copyright(_("Copyright (c) 2011 - 2019 Patrick Ulbrich and contributors."))
+		aboutdialog.set_copyright(_("Copyright (c) 2011 - 2020 Patrick Ulbrich and contributors."))
 		aboutdialog.set_logo_icon_name("mailnag")
 		aboutdialog.set_website("https://github.com/pulb/mailnag")
 		aboutdialog.set_website_label(_("Homepage"))
 		aboutdialog.set_license_type(Gtk.License.GPL_2_0)		
 		aboutdialog.set_authors([
 			"Patrick Ulbrich (maintainer)",
+			"Balló György",
 			"Edwin Smulders",
 			"Freeroot",
+			"James Powell",
 			"Leighton Earl",
 			"Matthias Mailänder",
 			"Oleg",
 			"Ralf Hersel",
+			"razer",
 			"Taylor Braun-Jones",
 			"Thomas Haider",
 			"Timo Kankare",
